@@ -5,6 +5,7 @@ from libinsitu.common import *
 from libinsitu.cdl import *
 from libinsitu.common import _prepare_properties
 from libinsitu.handlers import HANDLERS, InSituHandler, listNetworks
+from libinsitu.handlers.GenericCSVHandler import GenericCSVHandler
 from libinsitu.log import debug, info, warning, logger, LogContext, error
 import argparse
 
@@ -64,26 +65,49 @@ def list_files(in_files, handler) :
     return in_files
 
 
-def process_network(network, station_id, out_filename, args) :
+def process_network(network, station_id, args) :
 
-    # Get properties for this station
-    properties = getProperties(network, station_id)
+    if args.mapping :
 
+        if not args.metadata :
+            raise Exception("Missing file path for custom station metadata")
 
-    handler : InSituHandler = HANDLERS[network](properties)
+        properties = getCustomProperties(
+            network,
+            station_id,
+            args.metadata)
+
+        handler = GenericCSVHandler(properties, args.mapping)
+    else:
+
+        # Check network
+        all_networks = listNetworks()
+        if not network in all_networks:
+            raise Exception("Bad Network %s. Should be one of %s" % (network, str(all_networks)))
+
+        # Get all properties
+        properties = getProperties(
+            network,
+            station_id)
+
+        handler : InSituHandler = HANDLERS[network](properties)
 
     in_files = list_files(args.in_files, handler)
 
-    new = not os.path.exists(out_filename)
+    new = not os.path.exists(args.out)
 
     # If file exists, put it in read only until we process an input file, to avoid changing its mtime
     mode = "w" if new else "r"
-    ncfile = Dataset(out_filename, mode=mode)
+    ncfile = Dataset(args.out, mode=mode)
 
     if new :
         # Nc File does not exist ==> create it
-        info("File '%s' was not there. Initializing it.", out_filename)
-        init_nc(ncfile, properties, [])
+        info("File '%s' was not there. Initializing it.", args.out)
+        init_nc(
+            ncfile,
+            properties,
+            data_vars=[],
+            custom_cdl=args.cdl)
 
     min_date = None
     max_date = None
@@ -111,7 +135,7 @@ def process_network(network, station_id, out_filename, args) :
                 # First processed file ? reopen the file in write mode => this will update its mtime
                 if mode == "r" :
                     ncfile.close()
-                    ncfile = Dataset(out_filename, mode="a")
+                    ncfile = Dataset(args.out, mode="a")
                     mode = "a"
 
                 data = handler.read_chunk(infile)
@@ -119,7 +143,8 @@ def process_network(network, station_id, out_filename, args) :
                 chunk_start, chunk_end = process_chunck(
                     data, ncfile, properties,
                     check=args.check,
-                    strict_resolution=args.strict_resolution)
+                    strict_resolution=args.strict_resolution,
+                    custom_cdl=args.cdl)
 
                 # Store extent of update
                 min_date = nmin(chunk_start, min_date)
@@ -239,7 +264,8 @@ def dataframe_to_netcdf(
         process_qc=True,
         close=True,
         network_props = dict(),
-        station_props = dict()) :
+        station_props = dict(),
+        custom_cdl=None) :
     """
     Transforms a Dataframe of solar irradiance to a well encoded NetCDF file.
 
@@ -254,6 +280,7 @@ def dataframe_to_netcdf(
     :param close: Close netcdf file at the end of process
     :param network_props: Dict of additional network properties (without `Network_` prefix), as used in base.cdl
     :param station_props: Dict of additional station properties (without `Station_` prefix) as used in base.cdl
+    :param custom_cdl: File path to custom schema.cdl file
     """
 
     properties = _prepare_properties(
@@ -289,7 +316,9 @@ def dataframe_to_netcdf(
         init_nc(ncfile, properties, [])
 
         # Transform data
-        process_chunck(data, ncfile, properties)
+        process_chunck(
+            data, ncfile, properties,
+            custom_cdl=custom_cdl)
 
         if process_qc :
             update_qc_flags(ncfile)
@@ -302,7 +331,7 @@ def dataframe_to_netcdf(
 
 
 
-def process_chunck(data, ncfile, properties, strict_resolution=False, check=False):
+def process_chunck(data, ncfile, properties, strict_resolution=False, check=False, custom_cdl=None):
 
     if data is None or len(data) == 0 :
         warning("Chunk is empty")
@@ -328,7 +357,7 @@ def process_chunck(data, ncfile, properties, strict_resolution=False, check=Fals
     missing_vars = list(col for col in columns if not col in ncfile.variables)
     if len(missing_vars) > 0:
         info("Adding missing vars : %s", missing_vars)
-        init_nc(ncfile, properties, missing_vars)
+        init_nc(ncfile, properties, missing_vars, custom_cdl=custom_cdl)
 
     # Ensure all timestamps fall into resolution
     exact_idx = (times_sec % resolution_s) == 0
@@ -421,16 +450,23 @@ def parser() :
     parser = argparse.ArgumentParser(description='Transforms In-Situ data into NetCDF files')
     parser.add_argument('out', metavar='<out.nc>', type=str, help='Output file')
     parser.add_argument('in_files', metavar='<file|dir>', nargs='+', help='Input files or folders')
-    parser.add_argument('--network', '-n', help='Network name', required=True, choices=listNetworks())
+    parser.add_argument('--network', '-n', help='Network name', required=True)
     parser.add_argument('--station-id', '-s', metavar='<SID>', help='Station ID', required=True)
-    parser.add_argument('--incremental', '-i', default=False, action='store_true',
-                        help="Incremental mode, skipping input files having a '.done' status files")
-    parser.add_argument('--strict-resolution', '-sr', default=False, action='store_true',
-                        help="Skip chunks having a different resulution")
+    parser.add_argument('--mapping', '-m', metavar='<mapping.json>', help='Use a generic parser with custom mapping. Tu be used in conjonction with --metadata')
+    parser.add_argument('--metadata', '-md', metavar='<station-meta.csv>', help='Use custom station metadata for this network')
+    parser.add_argument('--cdl', metavar='<schema.cdl>', help="Use a custom CDL (NetCDF schema)")
+    parser.add_argument(
+        '--incremental', '-i', default=False, action='store_true',
+        help="Incremental mode, skipping input files having a '.done' status files")
+    parser.add_argument(
+        '--strict-resolution', '-sr', default=False, action='store_true',
+        help="Skip chunks having a different resulution")
     parser.add_argument('--no-qc', default=False, action='store_true', help="Do not compute QC flags")
     parser.add_argument('--check', '-c', default=False, action='store_true', help="Check potential override of data")
-    parser.add_argument('--status-folder', '-f', metavar='<folder>', type=dir_path,
-                        help='Separate folder for .done/.err files')
+    parser.add_argument(
+        '--status-folder', '-f',
+        metavar='<folder>', type=dir_path,
+        help='Separate folder for .done/.err files')
     return parser
 
 def main():
@@ -441,7 +477,7 @@ def main():
     station_id  = args.station_id
 
     with LogContext(network=network, station_id=station_id):
-        process_network(network, station_id, args.out, args)
+        process_network(network, station_id, args)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
