@@ -11,7 +11,7 @@ MAPPING = dict(Gg_pyr=GLOBAL_VAR)
 
 class ISEPVLive(InSituHandler) :
 
-    def _read_chunk(self, stream) -> DataFrame:
+    def _read_chunk(self, stream, entryname=None) -> DataFrame:
         data = pd.read_csv(stream,sep='\t',parse_dates=['datetime'],index_col=0)
         data = map_cols(data, MAPPING)
         return data
